import React, { useState, useEffect } from 'react';
import { Card, Row, Col, Form, InputGroup, Button } from 'react-bootstrap';
import { Eye } from 'lucide-react';
import RangeSlider from './RangeSlider';
import '../styles/DatabaseFilter.scss';

export default function DatabaseFilter() {
    // 类别选项数据
    const categories = [
        'Phones & Electronics',
        'Homes Supplies',
        'Kitchenware',
        'Textiles & Soft Furnishings',
        'Household Appliances',
    ];

    // 电商评级数据
    const ecommerceRatings = ['L1', 'L2', 'L3', 'L4', 'L5', 'L6', 'L7'];

    // 曝光评级数据
    const exposureRatings = ['KOC-1', 'KOC-2', 'KOL-1', 'KOL-2', 'KOL-3'];

    // GMV 范围选项
    const gmvRanges = [
        { label: '$0 - $5k', min: 0, max: 5000 },
        { label: '$5k - $25k', min: 5000, max: 25000 },
        { label: '$25k - $60k', min: 25000, max: 60000 },
        { label: '$60k - $150k', min: 60000, max: 150000 },
        { label: '$150k - $400k', min: 150000, max: 400000 },
        { label: '$400k - $1500k', min: 400000, max: 1500000 },
        { label: '$1500k+', min: 1500000, max: Number.MAX_SAFE_INTEGER },
    ];

    // 预定义的离散点值
    const discreteValues = [0, 100, 1000, 10000, 100000, 250000, 500000];

    // 找到最接近的离散值索引
    const findClosestDiscreteIndex = (value) => {
        let closestIndex = 0;
        let minDiff = Math.abs(discreteValues[0] - value);

        for (let i = 1; i < discreteValues.length; i++) {
            const diff = Math.abs(discreteValues[i] - value);
            if (diff < minDiff) {
                minDiff = diff;
                closestIndex = i;
            }
        }

        return closestIndex;
    };

    // 存储选择的状态
    const [selectedCategory, setSelectedCategory] = useState('Homes Supplies');
    const [selectedEcommerceRatings, setSelectedEcommerceRatings] = useState(['L2', 'L3']);
    const [selectedExposureRatings, setSelectedExposureRatings] = useState([]);
    const [selectedGmvRanges, setSelectedGmvRanges] = useState(['$5k - $25k', '$25k - $60k']);

    // 视频观看量过滤器数值范围 - 使用离散值初始化
    const [viewsRange, setViewsRange] = useState([0, 100000]);
    const [minViews, setMinViews] = useState(0);
    const [maxViews, setMaxViews] = useState(100000);

    // 处理类别选择
    const handleCategorySelect = (category) => {
        setSelectedCategory(category);
    };

    // 处理电商评级选择
    const handleEcommerceRatingSelect = (rating) => {
        if (selectedEcommerceRatings.includes(rating)) {
            setSelectedEcommerceRatings(selectedEcommerceRatings.filter((r) => r !== rating));
        } else {
            setSelectedEcommerceRatings([...selectedEcommerceRatings, rating]);
        }
    };

    // 处理曝光评级选择
    const handleExposureRatingSelect = (rating) => {
        if (selectedExposureRatings.includes(rating)) {
            setSelectedExposureRatings(selectedExposureRatings.filter((r) => r !== rating));
        } else {
            setSelectedExposureRatings([...selectedExposureRatings, rating]);
        }
    };

    // 处理GMV范围选择
    const handleGmvRangeSelect = (range) => {
        if (selectedGmvRanges.includes(range)) {
            setSelectedGmvRanges(selectedGmvRanges.filter((r) => r !== range));
        } else {
            setSelectedGmvRanges([...selectedGmvRanges, range]);
        }
    };

    // 处理视图范围更新
    const handleViewsRangeChange = (newRange) => {
        setViewsRange(newRange);
        setMinViews(newRange[0]);
        setMaxViews(newRange[1]);
    };

    // 处理min input变更
    const handleMinViewsChange = (e) => {
        const inputValue = parseInt(e.target.value) || 0;
        setMinViews(inputValue);
    };

    // 处理max input变更
    const handleMaxViewsChange = (e) => {
        const inputValue = parseInt(e.target.value) || 0;
        setMaxViews(inputValue);
    };

    // 当输入框失去焦点时，转换为最接近的离散值
    const handleInputBlur = (type) => {
        if (type === 'min') {
            // 找到最接近的离散值
            const closestIndex = findClosestDiscreteIndex(minViews);
            const discreteValue = discreteValues[closestIndex];

            // 确保最小值不超过最大值
            const finalValue = Math.min(discreteValue, maxViews);

            setMinViews(finalValue);
            setViewsRange([finalValue, viewsRange[1]]);
        } else {
            // 找到最接近的离散值
            const closestIndex = findClosestDiscreteIndex(maxViews);
            const discreteValue = discreteValues[closestIndex];

            // 确保最大值不小于最小值
            const finalValue = Math.max(discreteValue, minViews);

            setMaxViews(finalValue);
            setViewsRange([viewsRange[0], finalValue]);
        }
    };

    // 格式化显示值的函数
    const formatValue = (value) => {
        if (value >= 1000000) {
            return `${(value / 1000000).toFixed(1)}M`;
        }
        if (value >= 1000) {
            return `${(value / 1000).toFixed(0)}k`;
        }
        return value;
    };

    return (
        <Card className='shadow-sm mb-4 filter-card'>
            <Card.Body>
                <h3 className='mb-4'>Filter</h3>

                {/* 类别筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>Category</h5>
                    <div className='filter-options'>
                        {categories.map((category) => (
                            <Button
                                key={category}
                                variant={selectedCategory === category ? 'primary' : 'light'}
                                className='rounded-pill'
                                onClick={() => handleCategorySelect(category)}
                            >
                                {category}
                            </Button>
                        ))}
                    </div>
                </div>

                {/* 电商评级筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>E-commerce Rating</h5>
                    <div className='filter-options'>
                        {ecommerceRatings.map((rating) => (
                            <Button
                                key={rating}
                                variant={selectedEcommerceRatings.includes(rating) ? 'primary' : 'light'}
                                className='rounded-pill'
                                onClick={() => handleEcommerceRatingSelect(rating)}
                            >
                                {rating}
                            </Button>
                        ))}
                    </div>
                </div>

                {/* 曝光评级筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>Exposure Rating</h5>
                    <div className='filter-options'>
                        {exposureRatings.map((rating) => (
                            <Button
                                key={rating}
                                variant={selectedExposureRatings.includes(rating) ? 'primary' : 'light'}
                                className='rounded-pill'
                                onClick={() => handleExposureRatingSelect(rating)}
                            >
                                {rating}
                            </Button>
                        ))}
                    </div>
                </div>

                {/* GMV筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>GMV</h5>
                    <div className='filter-options'>
                        {gmvRanges.map((range) => (
                            <Button
                                key={range.label}
                                variant={selectedGmvRanges.includes(range.label) ? 'primary' : 'light'}
                                className='rounded-pill'
                                onClick={() => handleGmvRangeSelect(range.label)}
                            >
                                {range.label}
                            </Button>
                        ))}
                    </div>
                </div>

                {/* 视频观看量筛选 */}
                <div className='filter-item'>
                    <h5 className='filter-title'>Views</h5>
                    <div className='filter-options filter-views'>
                        <RangeSlider min={0} max={500000} value={viewsRange} onChange={handleViewsRangeChange} />

                        <div className='range-input'>
                            <InputGroup>
                                <InputGroup.Text>
                                    <Eye size={16} />
                                </InputGroup.Text>
                                <Form.Control
                                    type='number'
                                    value={minViews}
                                    onChange={handleMinViewsChange}
                                    onBlur={() => handleInputBlur('min')}
                                />
                            </InputGroup>
                            <span>-</span>
                            <InputGroup>
                                <InputGroup.Text>
                                    <Eye size={16} />
                                </InputGroup.Text>
                                <Form.Control
                                    type='number'
                                    value={maxViews}
                                    onChange={handleMaxViewsChange}
                                    onBlur={() => handleInputBlur('max')}
                                />
                            </InputGroup>
                        </div>
                    </div>
                </div>
            </Card.Body>
        </Card>
    );
}
