import React, { useState } from 'react';
import { Link, useLocation } from 'react-router-dom';
import { Nav, Accordion } from 'react-bootstrap';
import { Settings, ChevronDown, Blocks, SquareActivity, LayoutDashboard, Mail, UserSearch, Heart } from 'lucide-react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import logo from '@/assets/logo.png';
import '../styles/sidebar.scss';

// Organized menu items
const menuItems = [
    {
        id: 'creator-discovery',
        title: 'Creator Discovery',
        path: '/creator-discovery',
        icon: <UserSearch style={{ width: 20, height: 20 }} />,
        hasSubmenu: false,
    },
    {
        id: 'creator-database',
        title: 'Creator Database',
        path: '/creator-database',
        icon: <Blocks style={{ width: 20, height: 20 }} />,
        hasSubmenu: true,
        submenuItems: [
            {
                id: 'tiktok',
                title: 'TikTok',
                path: '/creator-database/tiktok',
                icon: <FontAwesomeIcon style={{ width: 20, height: 20 }} icon='fa-brands fa-tiktok' />,
            },
            {
                id: 'instagram',
                title: 'Instagram',
                path: '/creator-database/instagram',
                icon: <FontAwesomeIcon style={{ width: 20, height: 20 }} icon='fa-brands fa-instagram' />,
            },
            {
                id: 'youtube',
                title: 'YouTube',
                path: '/creator-database/youtube',
                icon: <FontAwesomeIcon style={{ width: 20, height: 20 }} icon='fa-brands fa-youtube' />,
            },
        ],
    },
    {
        id: 'private-creators',
        title: 'Private Creators',
        path: '/private-creators',
        icon: <Heart style={{ width: 20, height: 20 }} />,
        hasSubmenu: true,
        submenuItems: [],
    },
    {
        id: 'deep-analysis',
        title: 'Deep Analysis',
        path: '/deep-analysis',
        icon: <SquareActivity style={{ width: 20, height: 20 }} />,
        hasSubmenu: false,
    },
    {
        id: 'brands',
        title: 'Brands',
        path: '/brands',
        icon: <LayoutDashboard style={{ width: 20, height: 20 }} />,
        hasSubmenu: false,
    },
    {
        id: 'creator-inbox',
        title: 'Creator Inbox',
        path: '/creator-inbox',
        icon: <Mail style={{ width: 20, height: 20 }} />,
        hasSubmenu: true,
        submenuItems: [],
    },
    {
        id: 'settings',
        title: 'Settings',
        path: '/settings',
        icon: <Settings style={{ width: 20, height: 20 }} />,
        hasSubmenu: false,
    },
];

export default function Sidebar() {
    const location = useLocation();
    const [expanded, setExpanded] = useState({});

    // 检查路径是否匹配当前路由
    const isActive = (path) => {
        return location.pathname === path || location.pathname.startsWith(`${path}/`);
    };

    // 检查是否有子项是激活状态
    const hasActiveChild = (item) => {
        if (!item.submenuItems) return false;
        return item.submenuItems.some((subItem) => isActive(subItem.path));
    };

    // 处理手风琴项的展开/折叠
    const handleAccordionToggle = (id) => {
        setExpanded((prev) => ({
            ...prev,
            [id]: !prev[id],
        }));
    };

    return (
        <div className='sidebar'>
            <div className='sidebar-header p-3 d-flex align-items-center'>
                <img src={logo} alt='OOIN Logo' width={48} height={48} className='me-2' />
                <div>
                    <div className='fw-bold'>OOIN Media</div>
                    <div className='small text-muted'>Creator Center</div>
                </div>
            </div>

            <Nav className='flex-column sidebar-nav'>
                {menuItems.map((item) => {
                    if (item.hasSubmenu) {
                        const isItemActive = isActive(item.path) || hasActiveChild(item);
                        const isOpen = expanded[item.id] || isItemActive;

                        return (
                            <Accordion key={item.id} className='sidebar-accordion' activeKey={isOpen ? item.id : null}>
                                <Accordion.Item eventKey={item.id} className='border-0 bg-transparent'>
                                    <Accordion.Header
                                        onClick={() => handleAccordionToggle(item.id)}
                                        className={isItemActive ? 'active' : ''}
                                    >
                                        <div className='d-flex align-items-center'>
                                            <span className='sidebar-icon me-2'>{item.icon}</span>
                                            {item.title}
                                        </div>
                                    </Accordion.Header>
                                    <Accordion.Body className='p-0'>
                                        <Nav className='flex-column sidebar-submenu'>
                                            {item.submenuItems &&
                                                item.submenuItems.map((subItem) => (
                                                    <Nav.Item key={`${item.id}-${subItem.id}`}>
                                                        <Nav.Link
                                                            as={Link}
                                                            to={subItem.path}
                                                            className={isActive(subItem.path) ? 'active' : ''}
                                                        >
                                                            <span className='sidebar-icon me-2'>{subItem.icon}</span>
                                                            {subItem.title}
                                                        </Nav.Link>
                                                    </Nav.Item>
                                                ))}
                                        </Nav>
                                    </Accordion.Body>
                                </Accordion.Item>
                            </Accordion>
                        );
                    } else {
                        return (
                            <Nav.Item key={item.id}>
                                <Nav.Link as={Link} to={item.path} className={isActive(item.path) ? 'active' : ''}>
                                    <span className='sidebar-icon me-2'>{item.icon}</span>
                                    {item.title}
                                </Nav.Link>
                            </Nav.Item>
                        );
                    }
                })}
            </Nav>
        </div>
    );
}
